import { JsonObject } from '../../types';
import { BaseWorkflowDeclaration } from '../../declaration';
import { HatchetClient } from '../../client/client';
type SingleMiddleware<T> = (input: JsonObject) => T | Promise<T>;
type SingleSerialize<T> = (input: T) => JsonObject | Promise<JsonObject>;
export interface Serializable<T = any> {
    deserialize: SingleMiddleware<T>;
    serialize: SingleSerialize<T>;
}
export interface Middleware {
    input: Serializable;
    output: Serializable;
}
export interface MiddlewareChain {
    middlewares: Middleware[];
}
export type MiddlewareFn<T = any> = (input: any) => T | Promise<T>;
/**
 * Binds middleware to a workflow's tasks
 * @param wf - The workflow declaration to bind middleware to
 * @param client - The HatchetClient instance
 * @returns The workflow with middleware bound to its tasks
 */
export declare function bindMiddleware(wf: BaseWorkflowDeclaration<any, any>, client: HatchetClient): Promise<BaseWorkflowDeclaration<any, any>>;
export declare function serializeInput(input: JsonObject, middleware?: Middleware[]): Promise<JsonObject>;
export declare function deserializeOutput(output: JsonObject, middleware?: Middleware[]): Promise<JsonObject>;
export {};
